import React, { useEffect, useState } from 'react';
import { Modal, Input, Row, Col, Select } from 'antd';

import { role } from '@/types/role';

import { getWeappList } from '@/services/weapp';

import { WeappItem } from '@/types/index';

const { Option } = Select;

const layout = {
  labelCol: { span: 5 },
  wrapperCol: { span: 16 },
};

interface IProps {
  visible: boolean;
  curClub: role;
  onChange: (e: React.ChangeEvent<HTMLInputElement>) => void;
  onsubmit: () => void;
  closeModal: () => void;
  onChangeMiniProgramList: (selectWeapp: WeappItem[]) => void;
}

const ClubModal: React.FC<IProps> = ({
  visible,
  curClub,
  onsubmit,
  onChange,
  closeModal,
  onChangeMiniProgramList,
}) => {
  const [weappList, setWeappList] = useState<WeappItem[]>([]);

  const [selectWeapp, setSelectWeapp] = useState<WeappItem[]>([]);

  const [loading, setLoading] = useState<boolean>(false);

  useEffect(() => {
    if (visible) {
      GetWeappList();
    }
  }, [visible]);

  const GetWeappList = async () => {
    // setLoading(true)
    const { data, status } = await getWeappList({ isPage: 1, pageSize: 10000, page: 1, total: 0 });
    // setLoading(false)
    if (status === 200) {
      console.log(data);
      setWeappList(data.entityList);
    }
  };

  const handleChange = (value: string[]) => {
    const r = weappList.filter((weapp) => value.includes(weapp.id));

    onChangeMiniProgramList(r);
  };

  const onOk = () => {
    onsubmit();
  };

  return (
    <Modal width="600px" visible={visible} title="修改俱乐部名称" onOk={onOk} onCancel={closeModal}>
      <Row align="middle">
        <Col span={6}>俱乐部分类:</Col>
        <Col span={12}>{curClub.previousLabel}</Col>
      </Row>
      <Row align="middle" style={{ marginTop: '14px' }}>
        <Col span={6}>俱乐部名称:</Col>
        <Col span={12}>
          <Input value={curClub.label} onChange={(e) => onChange(e)} />
        </Col>
      </Row>
      <Row align="middle" style={{ marginTop: '14px' }}>
        <Col span={6}>添加小程序:</Col>
        <Col span={12}>
          <Select
            mode="multiple"
            allowClear
            style={{ width: '100%' }}
            placeholder="点击添加小程序"
            defaultValue={curClub?.miniProgramList?.map((weapp) => weapp.id)}
            onChange={handleChange}
          >
            {weappList.map((weapp) => (
              <Option key={weapp.id} value={weapp.id}>
                {weapp.name}
              </Option>
            ))}
            {/* {children} */}
          </Select>
        </Col>
      </Row>
    </Modal>
  );
};

export default ClubModal;
