/**
 * request 网络请求工具
 * 更详细的 api 文档: https://github.com/umijs/umi-request
 */
import { extend } from 'umi-request';
import { notification, message } from 'antd';
import { BASE_URL, Token } from '@/utils/eventkey';

const codeMessage = {
  200: '服务器成功返回请求的数据。',
  201: '新建或修改数据成功。',
  202: '一个请求已经进入后台排队（异步任务）。',
  204: '删除数据成功。',
  400: '发出的请求有错误，服务器没有进行新建或修改数据的操作。',
  401: '用户没有权限（令牌、用户名、密码错误）。',
  403: '用户得到授权，但是访问是被禁止的。',
  404: '发出的请求针对的是不存在的记录，服务器没有进行操作。',
  406: '请求的格式不可得。',
  410: '请求的资源被永久删除，且不会再得到的。',
  422: '当创建一个对象时，发生一个验证错误。',
  500: '服务器发生错误，请检查服务器。',
  502: '网关错误。',
  503: '服务不可用，服务器暂时过载或维护。',
  504: '网关超时。',
};

/**
 * 异常处理程序
 */
const errorHandler = (error: { response: Response }): Response => {
  const { response } = error;
  console.log(response, '我是异常处理');

  if (response && response.status) {
    const errorText = codeMessage[response.status] || response.statusText;
    const { status, url } = response;

    // notification.error({
    //   message: `请求错误 ${status}: ${url}`,
    //   description: errorText,
    // });
  } else if (!response) {
    notification.error({
      description: '您的网络发生异常，无法连接服务器',
      message: '网络异常',
    });
  }
  return response;
};

/**
 * 配置request请求时的默认参数
 */
const request = extend({
  errorHandler, // 默认错误处理
  credentials: 'include', // 默认请求是否带上cookie
});

const headers = {
  Accept: 'application/json',
  'Content-Type': 'application/json',
  token: '',
};

// https://open.luojigou.vip

export const baseUrl: string = process.env.NODE_ENV === 'development' ? '/api' : '/zd-api';

request.interceptors.request.use(
  (url: string, options: any, mutUrl?: string) => {
    const requesturl = mutUrl || `${baseUrl}${url}`;
    const token = localStorage.getItem(Token);
    const Headers = { ...headers, token };
    return {
      url: requesturl,
      options: { ...options, headers: Headers, interceptors: true },
    };
  },
  { global: true },
);

request.interceptors.response.use(async (response, options) => {
  const r = await response.clone().json();
  if (r.code === 5001) {
    const { origin } = window.location;
    if (process.env.NODE_ENV === 'development') {
      // console.log(origin,'origin')
      window.location.href = `${origin}/#/user/login`;
    } else {
      window.location.href = `${origin}/tieba-admin/#/user/login`;
    }
  }

  if (r.code === 5000) {
    message.error(r.message);
  }

  return response;
});

export default request;
